// objective: test the \snippet command
// check: indexpage.xml

/** \mainpage
 *  A bubble sort algorithm
 *  First get the inputs
 *  \snippet snippet_test.cpp input
 *  Then do the bubbling
 *  \snippet{trimleft,nostrip} snippet_test.cpp bubble
 *  Then write the result
 *  \snippet{lineno,strip} snippet_test.cpp output
 */
