/* page base colors */
--page-background-color: white;
--page-foreground-color: black;
--page-link-color: ##50;
--page-visited-link-color: ##50;
--page-external-link-color: ##40;

/* index */
--index-odd-item-bg-color: ##F9;
--index-even-item-bg-color: white;
--index-header-color: black;
--index-separator-color: #A0A0A0;

/* header */
--header-background-color: ##FA;
--header-separator-color: ##CC;
--group-header-separator-color: ##DE;
--group-header-color: ##44;

--footer-foreground-color: ##33;
--footer-logo-width: 75px;
--citation-label-color: ##40;
--glow-color: cyan;

--title-background-color: white;
--title-separator-color: ##CC;

--blockquote-background-color: ##F8;
--blockquote-border-color: ##AA;

--scrollbar-thumb-color: ##CC;
--scrollbar-background-color: ##FA;

--icon-background-color: ##88;
--icon-foreground-color: white;
--icon-folder-open-fill-color: ##CC;
--icon-folder-fill-color: ##DD;
--icon-folder-border-color: ##60;
--icon-doc-fill-color: ##DD;
--icon-doc-border-color: ##60;

/* brief member declaration list */
--memdecl-background-color: ##FA;
--memdecl-foreground-color: #555;
--memdecl-template-color: ##60;
--memdecl-border-color: ##DA;

/* detailed member list */
--memdef-border-color: ##B4;
--memdef-title-background-color: ##E6;
--memdef-proto-background-color: ##F0;
--memdef-proto-text-color: ##2b;
--memdef-param-name-color: #602020;
--memdef-template-color: ##60;

/* tables */
--table-cell-border-color: ##37;
--table-header-background-color: ##47;
--table-header-foreground-color: ##ff;

/* labels */
--label-background-color: ##88;
--label-left-top-border-color: ##70;
--label-right-bottom-border-color: ##CC;
--label-foreground-color: white;

/** navigation bar/tree/menu */
--nav-background-color: ##FA;
--nav-foreground-color: ##45;
--nav-border-color: ##CC;
--nav-breadcrumb-separator-color: ##CC;
--nav-breadcrumb-active-bg: ##F0;
--nav-breadcrumb-color: ##44;
--nav-splitbar-bg-color: ##E0;
--nav-splitbar-handle-color: ##AA;
--nav-font-size-level1: 13px;
--nav-font-size-level2: 10px;
--nav-font-size-level3: 9px;
--nav-text-normal-color: ##30;
--nav-menu-button-color: ##45;
--nav-menu-background-color: white;
--nav-menu-foreground-color: #555555;
--nav-menu-active-bg: ##E0;
--nav-menu-active-color: ##AA;
--nav-arrow-color: ##C0;
--nav-arrow-selected-color: ##A0;

/* sync icon */
--sync-icon-border-color: ##CC;
--sync-icon-background-color: ##FA;
--sync-icon-selected-background-color: ##F0;
--sync-icon-color: ##CC;
--sync-icon-selected-color: ##80;

/* table of contents */
--toc-background-color: ##F6;
--toc-border-color: ##DD;
--toc-header-color: ##60;
--toc-down-arrow-image: url("data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' version='1.1' height='10px' width='5px' fill='grey'><text x='0' y='5' font-size='10'>&%238595;</text></svg>");

/** search field */
--search-background-color: white;
--search-foreground-color: #909090;
--search-active-color: black;
--search-filter-background-color: rgba(255,255,255,.7);
--search-filter-backdrop-filter: blur(4px);
--search-filter-foreground-color: black;
--search-filter-border-color: rgba(150,150,150,.4);
--search-filter-highlight-text-color: white;
--search-filter-highlight-bg-color: ##50;
--search-results-foreground-color: ##58;
--search-results-background-color: rgba(255,255,255,.8);
--search-results-backdrop-filter: blur(4px);
--search-results-border-color: rgba(150,150,150,.4);
--search-box-border-color: ##C0;
--search-close-icon-bg-color: #A0A0A0;
--search-close-icon-fg-color: white;

/** code fragments */
--code-keyword-color: #008000;
--code-type-keyword-color: #604020;
--code-flow-keyword-color: #E08000;
--code-comment-color: #800000;
--code-preprocessor-color: #806020;
--code-string-literal-color: #002080;
--code-char-literal-color: #008080;
--code-xml-cdata-color: black;
--code-vhdl-digit-color: #FF00FF;
--code-vhdl-char-color: #000000;
--code-vhdl-keyword-color: #700070;
--code-vhdl-logic-color: #FF0000;
--fragment-foreground-color: black;
--fragment-background-color: ##FC;
--fragment-border-color: ##CC;
--fragment-lineno-border-color: #00FF00;
--fragment-lineno-background-color: #E8E8E8;
--fragment-lineno-foreground-color: black;
--fragment-lineno-link-fg-color: ##60;
--fragment-lineno-link-bg-color: #D8D8D8;
--fragment-lineno-link-hover-fg-color: ##60;
--fragment-lineno-link-hover-bg-color: #C8C8C8;
--fragment-copy-ok-color: #2EC82E;
--fragment-highlight-filter: -3;
--tooltip-foreground-color: black;
--tooltip-background-color: rgba(255,255,255,0.8);
--tooltip-arrow-background-color: white;
--tooltip-border-color: rgba(150,150,150,0.7);
--tooltip-backdrop-filter: blur(3px);
--tooltip-doc-color: grey;
--tooltip-declaration-color: #006318;
--tooltip-link-color: ##60;
--tooltip-shadow: 0 4px 8px 0 rgba(0,0,0,.25);
--fold-line-color: #808080;

/** font-family */
--font-family-normal: system-ui,-apple-system,Segoe UI,Roboto,Ubuntu,Cantarell,Noto Sans,sans-serif,BlinkMacSystemFont,"Segoe UI",Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
--font-family-monospace: 'JetBrains Mono',Consolas,Monaco,'Andale Mono','Ubuntu Mono',monospace,fixed;
--font-family-nav: 'Lucida Grande',Geneva,Helvetica,Arial,sans-serif;
--font-family-title: system-ui,-apple-system,Segoe UI,Roboto,Ubuntu,Cantarell,Noto Sans,sans-serif,BlinkMacSystemFont,"Segoe UI",Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
--font-family-toc: Verdana,'DejaVu Sans',Geneva,sans-serif;
--font-family-search: Arial,Verdana,sans-serif;
--font-family-icon: Arial,Helvetica;
--font-family-tooltip: Roboto,sans-serif;

/** special sections */
--warning-color-bg: #f8d1cc;
--warning-color-hl: #b61825;
--warning-color-text: #75070f;
--note-color-bg: #faf3d8;
--note-color-hl: #f3a600;
--note-color-text: #5f4204;
--todo-color-bg: #e4f3ff;
--todo-color-hl: #1879C4;
--todo-color-text: #274a5c;
--test-color-bg: #e8e8ff;
--test-color-hl: #3939C4;
--test-color-text: #1a1a5c;
--deprecated-color-bg: #ecf0f3;
--deprecated-color-hl: #5b6269;
--deprecated-color-text: #43454a;
--bug-color-bg: #e4dafd;
--bug-color-hl: #5b2bdd;
--bug-color-text: #2a0d72;
--invariant-color-bg: #d8f1e3;
--invariant-color-hl: #44b86f;
--invariant-color-text: #265532;
--satisfies-color-hl: #b61825;
--satisfies-color-bg: #f8d1cc;
--verifies-color-hl: #b61825;
--verifies-color-bg: #f8d1cc;

