/**
 * @file
 *
 * @ingroup B
 *
 * @brief more_100_b.c
 */

/**
 * @brief E in more_100_b.c
 *
 * @ingroup B
 */
enum E {
  /**
   * @brief A in more_100_b.c
   */
  A,

  /**
   * @brief B in more_100_b.c
   */
  B
};

/**
 * @brief D in more_100_b.c.
 *
 * @ingroup B
 */
#define D 1

/**
 * @brief f() in more_100_b.c.
 *
 * @ingroup B
 */
static void f(void) {};

/**
 * @brief T in more_100_b.c.
 *
 * @ingroup B
 */
typedef struct s T;

/**
 * @brief i in more_100_a.c.
 *
 * @ingroup B
 */
static int i;
