/* page base colors */
--page-background-color: black;
--page-foreground-color: #C9D1D9;
--page-link-color: ##A0;
--page-visited-link-color: ##A0;
--page-external-link-color: ##B0;

/* index */
--index-odd-item-bg-color: ##0A;
--index-even-item-bg-color: black;
--index-header-color: ##CC;
--index-separator-color: ##40;

/* header */
--header-background-color: ##06;
--header-separator-color: ##14;
--group-header-separator-color: ##20;
--group-header-color: ##A0;

--footer-foreground-color: ##76;
--footer-logo-width: 60px;
--citation-label-color: ##A0;
--glow-color: cyan;

--title-background-color: ##08;
--title-separator-color: ##25;

--blockquote-background-color: ##10;
--blockquote-border-color: ##30;

--scrollbar-thumb-color: ##35;
--scrollbar-background-color: ##06;

--icon-background-color: ##40;
--icon-foreground-color: ##CC;
--icon-folder-open-fill-color: ##60;
--icon-folder-fill-color: ##70;
--icon-folder-border-color: ##CC;
--icon-doc-fill-color: ##80;
--icon-doc-border-color: ##CC;

/* brief member declaration list */
--memdecl-background-color: ##0A;
--memdecl-foreground-color: #BBB;
--memdecl-template-color: ##90;
--memdecl-border-color: ##28;

/* detailed member list */
--memdef-border-color: ##28;
--memdef-title-background-color: ##1E;
--memdef-proto-background-color: ##1B;
--memdef-proto-text-color: ##AB;
--memdef-param-name-color: #D28757;
--memdef-template-color: ##90;

/* tables */
--table-cell-border-color: ##30;
--table-header-background-color: ##30;
--table-header-foreground-color: ##CC;

/* labels */
--label-background-color: ##44;
--label-left-top-border-color: ##60;
--label-right-bottom-border-color: ##30;
--label-foreground-color: #CCCCCC;

/** navigation bar/tree/menu */
--nav-background-color: ##10;
--nav-foreground-color: ##45;
--nav-border-color: ##25;
--nav-breadcrumb-separator-color: ##25;
--nav-breadcrumb-active-bg: ##20;
--nav-breadcrumb-color: ##A0;
--nav-splitbar-bg-color: ##30;
--nav-splitbar-handle-color: ##60;
--nav-font-size-level1: 13px;
--nav-font-size-level2: 10px;
--nav-font-size-level3: 9px;
--nav-text-normal-color: ##C0;
--nav-menu-button-color: ##C0;
--nav-menu-background-color: ##04;
--nav-menu-foreground-color: #BBBBBB;
--nav-menu-active-bg: ##20;
--nav-menu-active-color: ##D0;
--nav-arrow-color: ##60;
--nav-arrow-selected-color: ##80;

/* sync icon */
--sync-icon-border-color: ##25;
--sync-icon-background-color: ##10;
--sync-icon-selected-background-color: ##20;
--sync-icon-color: ##60;
--sync-icon-selected-color: ##70;

/* table of contents */
--toc-background-color: ##15;
--toc-border-color: ##24;
--toc-header-color: ##B0;
--toc-down-arrow-image: url("data:image/svg+xml;utf8,<svg xmlns='http://www.w3.org/2000/svg' version='1.1' height='10px' width='5px'><text x='0' y='5' font-size='10' fill='grey'>&%238595;</text></svg>");

/** search field */
--search-background-color: black;
--search-foreground-color: #C5C5C5;
--search-active-color: #F5F5F5;
--search-filter-background-color: ##10;
--search-filter-foreground-color: ##A0;
--search-filter-backdrop-filter: none;
--search-filter-border-color: ##90;
--search-filter-highlight-text-color: ##C5;
--search-filter-highlight-bg-color: ##30;
--search-results-background-color: black;
--search-results-foreground-color: ##A0;
--search-results-backdrop-filter: none;
--search-results-border-color: ##40;
--search-box-border-color: ##40;
--search-close-icon-bg-color: #909090;
--search-close-icon-fg-color: black;

/** code fragments */
--code-keyword-color: #CC99CD;
--code-type-keyword-color: #AB99CD;
--code-flow-keyword-color: #E08000;
--code-comment-color: #717790;
--code-preprocessor-color: #65CABE;
--code-string-literal-color: #7EC699;
--code-char-literal-color: #00E0F0;
--code-xml-cdata-color: #C9D1D9;
--code-vhdl-digit-color: #FF00FF;
--code-vhdl-char-color: #C0C0C0;
--code-vhdl-keyword-color: #CF53C9;
--code-vhdl-logic-color: #FF0000;
--fragment-foreground-color: #C9D1D9;
--fragment-background-color: ##08;
--fragment-border-color: #30363D;
--fragment-lineno-border-color: #30363D;
--fragment-lineno-background-color: black;
--fragment-lineno-foreground-color: #6E7681;
--fragment-lineno-link-fg-color: #6E7681;
--fragment-lineno-link-bg-color: #303030;
--fragment-lineno-link-hover-fg-color: #8E96A1;
--fragment-lineno-link-hover-bg-color: #505050;
--fragment-copy-ok-color: #0EA80E;
--fragment-highlight-filter: 5;
--tooltip-foreground-color: #C9D1D9;
--tooltip-background-color: #202020;
--tooltip-arrow-background-color: #202020;
--tooltip-backdrop-filter: none;
--tooltip-border-color: #C9D1D9;
--tooltip-doc-color: #D9E1E9;
--tooltip-declaration-color: #20C348;
--tooltip-link-color: #79C0FF;
--tooltip-shadow: none;
--fold-line-color: #808080;

/** font-family */
--font-family-normal: system-ui,-apple-system,Segoe UI,Roboto,Ubuntu,Cantarell,Noto Sans,sans-serif,BlinkMacSystemFont,"Segoe UI",Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
--font-family-monospace: 'JetBrains Mono',Consolas,Monaco,'Andale Mono','Ubuntu Mono',monospace,fixed;
--font-family-nav: 'Lucida Grande',Geneva,Helvetica,Arial,sans-serif;
--font-family-title: system-ui,-apple-system,Segoe UI,Roboto,Ubuntu,Cantarell,Noto Sans,sans-serif,BlinkMacSystemFont,"Segoe UI",Helvetica,Arial,sans-serif,"Apple Color Emoji","Segoe UI Emoji","Segoe UI Symbol";
--font-family-toc: Verdana,'DejaVu Sans',Geneva,sans-serif;
--font-family-search: Arial,Verdana,sans-serif;
--font-family-icon: Arial,Helvetica;
--font-family-tooltip: Roboto,sans-serif;

/** special sections */
--warning-color-bg: #2e1917;
--warning-color-hl: #ad2617;
--warning-color-text: #f5b1aa;
--note-color-bg: #3b2e04;
--note-color-hl: #f1b602;
--note-color-text: #ceb670;
--todo-color-bg: #163750;
--todo-color-hl: #1982D2;
--todo-color-text: #dcf0fa;
--test-color-bg: #121258;
--test-color-hl: #4242cf;
--test-color-text: #c0c0da;
--deprecated-color-bg: #2e323b;
--deprecated-color-hl: #738396;
--deprecated-color-text: #abb0bd;
--bug-color-bg: #2a2536;
--bug-color-hl: #7661b3;
--bug-color-text: #ae9ed6;
--invariant-color-bg: #303a35;
--invariant-color-hl: #76ce96;
--invariant-color-text: #cceed5;
--satisfies-color-hl: #ad2617;
--satisfies-color-bg: #2e1917;
--verifies-color-hl: #ad2617;
--verifies-color-bg: #2e1917;

