/*---------------- Search Box positioning */

#main-menu > li:last-child {
    /* This <li> object is the parent of the search bar */
    display: flex;
    justify-content: center;
    align-items: center;
    height: 43px;
    margin-right: 0;
}

