// objective: test different HTML style tags
// check: 086__style__tags_8h.xml
/**
\file

In the following the word tag has the style as indicated before it.
- This is a bold <b>tag</b>.
- This is a `strong` bold <strong>tag</strong>.
- This is an italic <i>tag</i>.
- This is an `em` italic <em>tag</em>.
- This is a strike through <strike>tag</strike>.
- This is a `s` strike through <s>tag</s>.
- This is an underline <u>tag</u>.
- This is an `ins` inserted <ins>tag</ins>.
- This is a deleted <del>tag</del>.
- This is a typewriter <tt>tag</tt>.
*/

