/**
 * @file
 *
 * @ingroup C
 *
 * @brief more_100_c.c
 */

/**
 * @defgroup A A
 */

/**
 * @defgroup B B
 */

/**
 * @defgroup C C
 */

/**
 * @file 100_a.c
 *
 * @ingroup A
 *
 * More for 100_a.c from more_100_c.c
 */

/**
 * @file more_100_b.c
 *
 * @ingroup B
 *
 * More for more_100_b.c from more_100_c.c
 */

/**
 * @enum E
 *
 * @ingroup A
 *
 * @ingroup C
 *
 * More for E in 100_a.c from more_100_c.c.
 */

/**
 * @enum E
 *
 * @ingroup B
 *
 * @ingroup C
 *
 * More for E in more_100_b.c from more_100_c.c.
 */

/**
 * @var E::A
 *
 * @ingroup A
 *
 * More for A in 100_a.c from more_100_c.c.
 */

/**
 * @var E::B
 *
 * @ingroup A
 *
 * More for B in 100_a.c from more_100_c.c.
 */

/**
 * @var E::A
 *
 * @ingroup B
 *
 * More for A in more_100_b.c from more_100_c.c.
 */

/**
 * @var E::B
 *
 * @ingroup B
 *
 * More for B in more_100_b.c from more_100_c.c.
 */

/**
 * @def D
 *
 * @ingroup A
 *
 * More for D in 100_a.c from more_100_c.c.
 */

/**
 * @def D
 *
 * @ingroup B
 *
 * More for D in more_100_b.c from more_100_c.c.
 */

/**
 * @fn static void f(void)
 *
 * @ingroup A
 *
 * More for f() in 100_a.c from more_100_c.c.
 */

/**
 * @fn static void f(void)
 *
 * @ingroup B
 *
 * More for f() in more_100_b.c from more_100_c.c.
 */

/**
 * @fn void g(void)
 *
 * @ingroup A
 *
 * More for g() in more_100_a.c from more_100_c.c.
 */

/**
 * @struct s
 *
 * @ingroup A
 *
 * @ingroup C
 *
 * More for s in 100_a.c from more_100_c.c.
 */

/**
 * @typedef struct s T
 *
 * @ingroup A
 *
 * More for T in 100_a.c from more_100_c.c.
 */

/**
 * @typedef struct s T
 *
 * @ingroup B
 *
 * More for T in more_100_b.c from more_100_c.c.
 */

/**
 * @var i
 *
 * @ingroup A
 *
 * More for i in 100_a.c from more_100_c.c.
 */

/**
 * @var i
 *
 * @ingroup B
 *
 * More for i in more_100_b.c from more_100_c.c.
 */

/**
 * @var j
 *
 * @ingroup A
 *
 * More for j in 100_a.c from more_100_c.c.
 */
